"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.fromInput = void 0;
var SSH_URL_PATTERN = /^(?<protocol>ssh:\/\/)?([a-zA-Z\d]+)@(?<host>[a-zA-Z\d.]+(:\d+)?)([/:])(?<namespace>[a-zA-Z\d-_]+)\/(?<slug>[a-zA-Z\d-_.]+)\.git$/;
var HTTPS_URL_PATTERN = /^(?<protocol>https:\/\/)(?<host>[a-zA-Z\d.]+)\/(?<namespace>[a-zA-Z\d-_]+)\/(?<slug>[a-zA-Z\d-_.]+)\.git$/;
var fromInput = function (input) {
    var urlConnection = input.urlConnection, workspace = input.workspace;
    var matchesSSh = urlConnection.match(SSH_URL_PATTERN);
    var matchesHttps = urlConnection.match(HTTPS_URL_PATTERN);
    var urlMatch = matchesSSh || matchesHttps;
    if (!urlMatch) {
        console.warn('invalid url connection', urlConnection);
        return;
    }
    var groups = urlMatch.groups || {};
    var host = groups['host'];
    var namespace = groups['namespace'];
    var slug = groups['slug'];
    var id = [workspace, namespace, slug].join('_');
    return {
        id: id,
        urlConnection: urlConnection,
        workspace: workspace,
        host: host,
        namespace: namespace,
        slug: slug
    };
};
exports.fromInput = fromInput;
